@@ -23,6 +23,7 @@ import multiprocessing
 import os
 import platform
 import shlex
+import signal
 import shutil
 import subprocess
 import sys
@@ -91,7 +92,7 @@ ZYPPER_INSTALL_SCRIPT = [
 ZYPPER_DEPENDENCIES = [
     # build system
     'autoconf', 'autoconf-archive', 'automake', 'cmake', 'make', 'patch', 'gcc-c++',
-    'libtool', 'which', 'pandoc', 'nasm', 'doxygen', 'graphviz',
+    'libtool', 'which', 'pandoc', 'nasm', 'doxygen', 'graphviz', 'systemd-devel',
     # contrib dependencies
     'curl', 'gzip', 'bzip2',
     # daemon
@@ -151,7 +152,7 @@ APT_DEPENDENCIES = [
     'libspeex-dev', 'libspeexdsp-dev', 'libswscale-dev', 'libtool',
     'libudev-dev', 'libyaml-cpp-dev', 'sip-tester', 'swig',
     'uuid-dev', 'yasm', 'libjsoncpp-dev', 'libva-dev', 'libvdpau-dev', 'libmsgpack-dev',
-    'pandoc', 'nasm', 'dpkg-dev'
+    'pandoc', 'nasm', 'dpkg-dev', 'libsystemd-dev'
 ]
 
 APT_CLIENT_DEPENDENCIES = [
@@ -180,7 +181,7 @@ PACMAN_DEPENDENCIES = [
     'gcc', 'ffmpeg', 'boost', 'cppunit', 'libdbus', 'dbus-c++', 'libe-book', 'expat',
     'jack', 'opus', 'pcre', 'libpulse', 'speex', 'speexdsp', 'libtool', 'yaml-cpp',
     'swig', 'yasm', 'make', 'patch', 'pkg-config',
-    'automake', 'libva', 'libvdpau', 'openssl', 'pandoc', 'nasm'
+    'automake', 'libva', 'libvdpau', 'openssl', 'pandoc', 'nasm', 'systemd-libs'
 ]
 
 PACMAN_CLIENT_DEPENDENCIES = [
@@ -304,17 +305,37 @@ def run_dependencies(args):
         sys.exit(1)
 
 
-def run_init():
+def run_init(args):
+    """Initialize the git submodules and install the commit-msg hook."""
     subprocess.run(["git", "submodule", "update", "--init"],
                    check=True)
 
-    hooks_directories = ['.git/hooks/', f'.git/modules/daemon/hooks']
-    for hooks_dir in hooks_directories:
+    client_hooks_dir = '.git/hooks'
+    daemon_hooks_dir = '.git/modules/daemon/hooks'
+
+    print("Installing commit-msg hooks...")
+    # Copy the commit-msg hook to all modules in the same way.
+    for hooks_dir in [client_hooks_dir, daemon_hooks_dir]:
         if not os.path.exists(hooks_dir):
             os.makedirs(hooks_dir)
-        copy_file("./extras/scripts/commit-msg", hooks_dir + "/commit-msg")
-        execute_script(['./extras/scripts/format.sh --install %(path)s'],
-                       {"path": hooks_dir})
+        copy_file("./extras/scripts/commit-msg",
+                  os.path.join(hooks_dir, "commit-msg"))
+
+    print("Installing pre-commit hooks...")
+    format_script = "./extras/scripts/format.py"
+    # Prepend with the python executable if on Windows (not WSL).
+    if sys.platform == 'win32':
+        format_script = f'python {format_script}'
+    # The client submodule has QML files, so we need to run qmlformat on it,
+    # and thus need to supply the Qt path.
+    execute_script([f'{format_script} --install {client_hooks_dir}'
+                    f' --qt {args.qt}' if args.qt else ''],
+                   {"path": client_hooks_dir})
+
+    # The daemon submodule has no QML files, so we don't need to run
+    # qmlformat on it, and thus don't need to supply the Qt path.
+    execute_script([f'{format_script} --install {daemon_hooks_dir}'],
+                   {"path": daemon_hooks_dir})
 
 
 def copy_file(src, dest):
@@ -347,8 +368,8 @@ def run_install(args):
                 ['python winmake.py -iv '
                  f'-s {args.sdk} -b daemon'])
         build_windows = 'extras/scripts/build-windows.py'
-        execute_script([f'python {build_windows} init'])
-        execute_script([f'python {build_windows}'])
+        execute_script([f'python {build_windows} --init'])
+        execute_script([f'python {build_windows} --qt={args.qt}'])
         return True
 
     # Unix-like platforms
@@ -438,6 +459,13 @@ def run_clean():
 
 def run_run(args):
     run_env = os.environ
+
+    if args.debug:
+        # Ignore the interruption signal when using GDB, as it's
+        # common to use C-c when debugging and we do not want the
+        # Python script to abort the debugging session.
+        signal.signal(signal.SIGINT, signal.SIG_IGN)
+
     try:
         if args.no_libwrap:
             jamid_log = open("daemon.log", 'a')
@@ -454,10 +482,18 @@ def run_run(args):
         client_log = open('jami.log', 'a')
         client_log.write('=== Starting client (%s) ===' %
                          time.strftime("%d/%m/%Y %H:%M:%S"))
-        client_process = subprocess.Popen(["./install/bin/jami", "-d"],
-                                          stdout=client_log,
-                                          stderr=client_log,
-                                          env=run_env)
+        jami_cmdline = ['install/bin/jami', '-d']
+        if args.debug:
+            jami_cmdline = ['gdb', '-ex', 'run', '--args'] + jami_cmdline
+
+        print('Invoking jami with: {}'.format(str.join(' ', jami_cmdline)))
+        if args.debug:
+            print('Debugging with GDB; NOT redirecting output to log file')
+        client_process = subprocess.Popen(
+            jami_cmdline,
+            stdout=False if args.debug else client_log,
+            stderr=False if args.debug else client_log,
+            env=run_env)
 
         with open('jami.pid', 'w') as f:
             f.write(str(client_process.pid)+'\n')
@@ -474,7 +510,10 @@ def run_run(args):
         print("\nCaught KeyboardInterrupt...")
 
     finally:
-        if args.background == False:
+        if args.debug:
+            # Restore the default signal handler for SIGINT.
+            signal.signal(signal.SIGINT, signal.SIG_DFL)
+        if not args.background:
             try:
                 # Only kill the processes if they are running, as they
                 # could have been closed by the user.
@@ -650,7 +689,8 @@ def main():
         run_dependencies(parsed_args)
 
     elif parsed_args.init:
-        run_init()
+        run_init(parsed_args)
+
     elif parsed_args.clean:
         run_clean()
 
