@@ -203,21 +203,18 @@ IncomingFile::process()
         auto shared = w.lock();
         if (!shared)
             return;
-        auto correct = shared->sha3Sum_.empty();
-        auto isEOF = shared->info_.bytesProgress == shared->info_.totalSize;
-        if (shared->stream_ && shared->stream_.is_open()) {
-            isEOF |= shared->stream_.eof();
+        if (shared->stream_ && shared->stream_.is_open())
             shared->stream_.close();
-        }
+        auto correct = shared->sha3Sum_.empty();
         if (!correct) {
             // Verify shaSum
             auto sha3Sum = fileutils::sha3File(shared->info_.path);
-            if (shared->sha3Sum_ == sha3Sum) {
-                JAMI_INFO() << "New file received: " << shared->info_.path;
-                correct = true;
-            } else if (isEOF || shared->isUserCancelled_) {
+            if (shared->isUserCancelled_) {
                 JAMI_WARN() << "Remove file, invalid sha3sum detected for " << shared->info_.path;
                 fileutils::remove(shared->info_.path, true);
+            } else if (shared->sha3Sum_ == sha3Sum) {
+                JAMI_INFO() << "New file received: " << shared->info_.path;
+                correct = true;
             } else {
                 JAMI_WARN() << "Invalid sha3sum detected, unfinished file: " << shared->info_.path;
             }
@@ -306,7 +303,8 @@ TransferManager::transferFile(const std::shared_ptr<ChannelSocket>& channel,
                               const std::string& interactionId,
                               const std::string& path,
                               size_t start,
-                              size_t end)
+                              size_t end,
+                              OnFinishedCb onFinished)
 {
     std::lock_guard<std::mutex> lk {pimpl_->mapMutex_};
     if (pimpl_->outgoings_.find(channel) != pimpl_->outgoings_.end())
@@ -316,7 +314,10 @@ TransferManager::transferFile(const std::shared_ptr<ChannelSocket>& channel,
     info.conversationId = pimpl_->to_;
     info.path = path;
     auto f = std::make_shared<OutgoingFile>(channel, fileId, interactionId, info, start, end);
-    f->onFinished([w = weak(), channel](uint32_t) {
+    f->onFinished([w = weak(), channel, onFinished = std::move(onFinished)](uint32_t code) {
+        if (code == uint32_t(libjami::DataTransferEventCode::finished) && onFinished) {
+            onFinished();
+        }
         // schedule destroy outgoing transfer as not needed
         dht::ThreadPool().computation().run([w, channel] {
             if (auto sthis_ = w.lock()) {
@@ -482,12 +483,17 @@ TransferManager::path(const std::string& fileId) const
 }
 
 void
-TransferManager::onIncomingProfile(const std::shared_ptr<ChannelSocket>& channel)
+TransferManager::onIncomingProfile(const std::shared_ptr<ChannelSocket>& channel, const std::string& sha3Sum)
 {
     if (!channel)
         return;
 
     auto name = channel->name();
+    auto sep = name.find_last_of('?');
+    std::string arguments;
+    if (sep != std::string::npos)
+        name = name.substr(0, sep);
+
     auto lastSep = name.find_last_of('/');
     auto fileId = name.substr(lastSep + 1);
 
@@ -517,7 +523,7 @@ TransferManager::onIncomingProfile(const std::shared_ptr<ChannelSocket>& channel
     fileutils::recursive_mkdir(recvDir);
     info.path =  fmt::format("{:s}{:s}_{:s}_{}", recvDir, deviceId, uri, tid);
 
-    auto ifile = std::make_shared<IncomingFile>(std::move(channel), info, "profile.vcf", "");
+    auto ifile = std::make_shared<IncomingFile>(std::move(channel), info, "profile.vcf", "", sha3Sum);
     auto res = pimpl_->vcards_.emplace(idx, std::move(ifile));
     if (res.second) {
         res.first->second->onFinished([w = weak(),
