@@ -141,6 +141,8 @@ std::atomic_bool Manager::initialized = {false};
 bool Manager::isIOSExtension = {false};
 #endif
 
+bool Manager::syncOnRegister = {true};
+
 static void
 copy_over(const std::string& srcPath, const std::string& destPath)
 {
@@ -679,12 +681,7 @@ Manager::ManagerPimpl::bindCallToConference(Call& call, Conference& conf)
     if (call.isConferenceParticipant())
         base_.detachParticipant(callId);
 
-
-
-    JAMI_DEBUG("[call:{}] bind to conference {} (callState={})",
-             callId,
-             confId,
-             state);
+    JAMI_DEBUG("[call:{}] bind to conference {} (callState={})", callId, confId, state);
 
     base_.getRingBufferPool().unBindAll(callId);
 
@@ -702,9 +699,7 @@ Manager::ManagerPimpl::bindCallToConference(Call& call, Conference& conf)
         conf.bindParticipant(callId);
         base_.answerCall(call);
     } else
-        JAMI_WARNING("[call:{}] call state {} not recognized for conference",
-                  callId,
-                  state);
+        JAMI_WARNING("[call:{}] call state {} not recognized for conference", callId, state);
 }
 
 //==============================================================================
@@ -748,7 +743,7 @@ Manager::setAutoAnswer(bool enable)
 }
 
 void
-Manager::init(const std::string& config_file)
+Manager::init(const std::string& config_file, libjami::InitFlag flags)
 {
     // FIXME: this is no good
     initialized = true;
@@ -846,7 +841,7 @@ Manager::init(const std::string& config_file)
         }
     }
 
-    {
+    if (!(flags & libjami::LIBJAMI_FLAG_NO_LOCAL_AUDIO)) {
         std::lock_guard<std::mutex> lock(pimpl_->audioLayerMutex_);
         pimpl_->initAudioDriver();
         if (pimpl_->audiodriver_) {
@@ -2822,9 +2817,10 @@ Manager::loadAccountMap(const YAML::Node& node)
                                                          + DIR_SEPARATOR_STR + "config.yml"] {
             if (fileutils::isFile(configFile)) {
                 try {
+                    auto configNode = YAML::LoadFile(configFile);
                     if (auto a = accountFactory.createAccount(JamiAccount::ACCOUNT_TYPE, dir)) {
                         auto config = a->buildConfig();
-                        config->unserialize(YAML::LoadFile(configFile));
+                        config->unserialize(configNode);
                         a->setConfig(std::move(config));
                     }
                 } catch (const std::exception& e) {
@@ -2918,10 +2914,10 @@ Manager::sendTextMessage(const std::string& accountID,
             if (pluginChatManager.hasHandlers()) {
                 auto cm = std::make_shared<JamiMessage>(accountID, to, false, payloads, fromPlugin);
                 pluginChatManager.publishMessage(cm);
-                return acc->sendTextMessage(cm->peerId, cm->data, 0, onlyConnected);
+                return acc->sendTextMessage(cm->peerId, "", cm->data, 0, onlyConnected);
             } else
 #endif // ENABLE_PLUGIN
-                return acc->sendTextMessage(to, payloads, 0, onlyConnected);
+                return acc->sendTextMessage(to, "", payloads, 0, onlyConnected);
         } catch (const std::exception& e) {
             JAMI_ERR("Exception during text message sending: %s", e.what());
         }
@@ -3051,10 +3047,9 @@ Manager::createSinkClients(
         }
         if (participant.w && participant.h && !participant.videoMuted) {
             auto currentSink = getSinkClient(sinkId);
-            if (!accountId.empty() &&
-                currentSink &&
-                string_remove_suffix(participant.uri, '@') == getAccount(accountId)->getUsername() &&
-                participant.device == getAccount<JamiAccount>(accountId)->currentDeviceId()) {
+            if (!accountId.empty() && currentSink
+                && string_remove_suffix(participant.uri, '@') == getAccount(accountId)->getUsername()
+                && participant.device == getAccount<JamiAccount>(accountId)->currentDeviceId()) {
                 // This is a local sink that must already exist
                 continue;
             }
@@ -3149,14 +3144,15 @@ Manager::getJamiPluginManager() const
 }
 #endif
 
-std::optional<std::weak_ptr<ChannelSocket>>
-Manager::gitSocket(const std::string& accountId,
-                   const std::string& deviceId,
-                   const std::string& conversationId)
+std::shared_ptr<ChannelSocket>
+Manager::gitSocket(std::string_view accountId,
+                   std::string_view deviceId,
+                   std::string_view conversationId)
 {
     if (const auto acc = getAccount<JamiAccount>(accountId))
-        return acc->gitSocket(DeviceId(deviceId), conversationId);
-    return std::nullopt;
+        if (auto convModule = acc->convModule())
+            return convModule->gitSocket(deviceId, conversationId);
+    return nullptr;
 }
 
 std::map<std::string, std::string>
@@ -3247,4 +3243,13 @@ Manager::eraseGitTransport(git_smart_subtransport* tr)
     pimpl_->gitTransports_.erase(tr);
 }
 
+tls::CertificateStore&
+Manager::certStore(const std::string& accountId) const
+{
+    if (const auto& account = getAccount<JamiAccount>(accountId)) {
+        return account->certStore();
+    }
+    throw std::runtime_error("No account found");
+}
+
 } // namespace jami
