@@ -34,7 +34,7 @@ extern const QString defaultDownloadPath;
 
 // clang-format off
 #define KEYS \
-    X(MinimizeOnClose, true) \
+    X(MinimizeOnClose, false) \
     X(DownloadPath, defaultDownloadPath) \
     X(ScreenshotPath, {}) \
     X(EnableNotifications, true) \
@@ -58,7 +58,9 @@ extern const QString defaultDownloadPath;
     X(LANG, "SYSTEM") \
     X(PositionShareDuration, 15) \
     X(PositionShareLimit, true) \
-    X(FlipSelf, false)
+    X(FlipSelf, true) \
+    X(ShowMardownOption, false) \
+    X(ShowSendOption, false)
 
 /*
  * A class to expose settings keys in both c++ and QML.
@@ -116,6 +118,8 @@ public:
     Q_INVOKABLE QVariant getValue(const Settings::Key key);
     Q_INVOKABLE void setValue(const Settings::Key key, const QVariant& value = {});
 
+    Q_INVOKABLE QVariant getDefault(const Settings::Key key) const;
+
     QString getLanguage();
 
     void loadTranslations();
