@@ -25,6 +25,7 @@
 
 #include "appsettingsmanager.h"
 #include "qtutils.h"
+#include "messageparser.h"
 
 #include <api/datatransfermodel.h>
 
@@ -48,7 +49,7 @@ MessagesAdapter::MessagesAdapter(AppSettingsManager* settingsManager,
                                  QObject* parent)
     : QmlAdapterBase(instance, parent)
     , settingsManager_(settingsManager)
-    , previewEngine_(previewEngine)
+    , messageParser_(new MessageParser(previewEngine, this))
     , filteredMsgListModel_(new FilteredMsgListModel(this))
     , mediaInteractions_(std::make_unique<MessageListModel>())
     , timestampTimer_(new QTimer(this))
@@ -71,8 +72,8 @@ MessagesAdapter::MessagesAdapter(AppSettingsManager* settingsManager,
         set_mediaMessageListModel(QVariant::fromValue(mediaInteractions_.get()));
     });
 
-    connect(previewEngine_, &PreviewEngine::infoReady, this, &MessagesAdapter::onPreviewInfoReady);
-    connect(previewEngine_, &PreviewEngine::linkified, this, &MessagesAdapter::onMessageLinkified);
+    connect(messageParser_, &MessageParser::messageParsed, this, &MessagesAdapter::onMessageParsed);
+    connect(messageParser_, &MessageParser::linkInfoReady, this, &MessagesAdapter::onLinkInfoReady);
 
     connect(timestampTimer_, &QTimer::timeout, this, &MessagesAdapter::timestampUpdated);
     timestampTimer_->start(timestampUpdateIntervalMs_);
@@ -254,12 +255,16 @@ void
 MessagesAdapter::copyToDownloads(const QString& interactionId, const QString& displayName)
 {
     auto downloadDir = lrcInstance_->accountModel().downloadDirectory;
-    if (auto accInfo = &lrcInstance_->getCurrentAccountInfo())
-        accInfo->dataTransferModel->copyTo(lrcInstance_->get_currentAccountId(),
-                                           lrcInstance_->get_selectedConvUid(),
-                                           interactionId,
-                                           downloadDir,
-                                           displayName);
+    if (auto accInfo = &lrcInstance_->getCurrentAccountInfo()) {
+        auto dest = accInfo->dataTransferModel->copyTo(lrcInstance_->get_currentAccountId(),
+                                                       lrcInstance_->get_selectedConvUid(),
+                                                       interactionId,
+                                                       downloadDir,
+                                                       displayName);
+        if (!dest.isEmpty()) {
+            Q_EMIT fileCopied(dest);
+        }
+    }
 }
 
 void
@@ -336,8 +341,8 @@ MessagesAdapter::onPaste()
         // Extract the local paths of the files.
         for (int i = 0; i < urlList.size(); ++i) {
             // Trim file:// or file:/// from url.
-            QString filePath = urlList.at(i).toString().remove(
-                QRegularExpression("^file:\\/{2,3}"));
+            const static QRegularExpression fileSchemeRe("^file:\\/{2,3}");
+            QString filePath = urlList.at(i).toString().remove(fileSchemeRe);
             Q_EMIT newFilePasted(filePath);
         }
     } else {
@@ -441,6 +446,24 @@ MessagesAdapter::onNewInteraction(const QString& convUid,
     }
 }
 
+void
+MessagesAdapter::onMessageParsed(const QString& messageId, const QString& parsed)
+{
+    const QString& convId = lrcInstance_->get_selectedConvUid();
+    const QString& accId = lrcInstance_->get_currentAccountId();
+    auto& conversation = lrcInstance_->getConversationFromConvUid(convId, accId);
+    conversation.interactions->setParsedMessage(messageId, parsed);
+}
+
+void
+MessagesAdapter::onLinkInfoReady(const QString& messageId, const QVariantMap& info)
+{
+    const QString& convId = lrcInstance_->get_selectedConvUid();
+    const QString& accId = lrcInstance_->get_currentAccountId();
+    auto& conversation = lrcInstance_->getConversationFromConvUid(convId, accId);
+    conversation.interactions->addHyperlinkInfo(messageId, info);
+}
+
 void
 MessagesAdapter::acceptInvitation(const QString& convId)
 {
@@ -536,15 +559,6 @@ MessagesAdapter::removeContact(const QString& convUid, bool banContact)
     accInfo.contactModel->removeContact(contactUri, banContact);
 }
 
-void
-MessagesAdapter::onPreviewInfoReady(QString messageId, QVariantMap info)
-{
-    const QString& convId = lrcInstance_->get_selectedConvUid();
-    const QString& accId = lrcInstance_->get_currentAccountId();
-    auto& conversation = lrcInstance_->getConversationFromConvUid(convId, accId);
-    conversation.interactions->addHyperlinkInfo(messageId, info);
-}
-
 void
 MessagesAdapter::onConversationMessagesLoaded(uint32_t loadingRequestId, const QString& convId)
 {
@@ -554,21 +568,13 @@ MessagesAdapter::onConversationMessagesLoaded(uint32_t loadingRequestId, const Q
 }
 
 void
-MessagesAdapter::parseMessageUrls(const QString& messageId,
-                                  const QString& msg,
-                                  bool showPreview,
-                                  QColor color)
+MessagesAdapter::parseMessage(const QString& msgId,
+                              const QString& msg,
+                              bool showPreview,
+                              const QColor& linkColor,
+                              const QColor& backgroundColor)
 {
-    previewEngine_->parseMessage(messageId, msg, showPreview, color);
-}
-
-void
-MessagesAdapter::onMessageLinkified(const QString& messageId, const QString& linkified)
-{
-    const QString& convId = lrcInstance_->get_selectedConvUid();
-    const QString& accId = lrcInstance_->get_currentAccountId();
-    auto& conversation = lrcInstance_->getConversationFromConvUid(convId, accId);
-    conversation.interactions->linkifyMessage(messageId, linkified);
+    messageParser_->parseMessage(msgId, msg, showPreview, linkColor, backgroundColor);
 }
 
 void
@@ -643,7 +649,7 @@ MessagesAdapter::getMediaInfo(const QString& msg)
         = "<body style='margin:0;padding:0;'>"
           "<%1 style='width:100%;height:%2;outline:none;background-color:#f1f3f4;"
           "object-fit:cover;' "
-          "controls controlsList='nodownload' src='file://%3' type='%4'/></body>";
+          "controls controlsList='nodownload noplaybackrate' src='file://%3' type='%4'/></body>";
     QMimeDatabase db;
     QMimeType mime = db.mimeTypeForFile(filePath);
     QVariantMap fileInfo = isLocalImage(mime.name());
@@ -652,19 +658,23 @@ MessagesAdapter::getMediaInfo(const QString& msg)
     }
     static const QRegExp vPattern("(video/)(avi|mov|webm|webp|rmvb)$", Qt::CaseInsensitive);
     vPattern.indexIn(mime.name());
-    QString type = vPattern.capturedTexts().size() == 3 ? vPattern.capturedTexts()[1] : "";
+    auto captured = vPattern.capturedTexts();
+    QString type = captured.size() == 3 ? captured[1] : "";
     if (!type.isEmpty()) {
         return {
             {"isVideo", true},
+            {"isAudio", false},
             {"html", html.arg("video", "100%", filePath, mime.name())},
         };
     } else {
         static const QRegExp aPattern("(audio/)(ogg|flac|wav|mpeg|mp3)$", Qt::CaseInsensitive);
         aPattern.indexIn(mime.name());
-        type = aPattern.capturedTexts().size() == 3 ? aPattern.capturedTexts()[1] : "";
+        captured = aPattern.capturedTexts();
+        type = captured.size() == 3 ? captured[1] : "";
         if (!type.isEmpty()) {
             return {
                 {"isVideo", false},
+                {"isAudio", true},
                 {"html", html.arg("audio", "54px", filePath, mime.name())},
             };
         }
@@ -676,9 +686,10 @@ bool
 MessagesAdapter::isRemoteImage(const QString& msg)
 {
     // TODO: test if all these open in the AnimatedImage component
-    QRegularExpression pattern("[^\\s]+(.*?)\\.(jpg|jpeg|png|gif|apng|webp|avif|flif)$",
-                               QRegularExpression::CaseInsensitiveOption);
-    QRegularExpressionMatch match = pattern.match(msg);
+    const static QRegularExpression
+        imageRe("[^\\s]+(.*?)\\.(jpg|jpeg|png|gif|apng|webp|avif|flif)$",
+                QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch match = imageRe.match(msg);
     return match.hasMatch();
 }
 
@@ -731,7 +742,7 @@ MessagesAdapter::getFormattedDay(const quint64 timestamp)
 }
 
 void
-MessagesAdapter::startSearch(QString& text, bool isMedia)
+MessagesAdapter::startSearch(const QString& text, bool isMedia)
 {
     mediaInteractions_.reset(new MessageListModel(this));
     set_mediaMessageListModel(QVariant::fromValue(mediaInteractions_.get()));
@@ -753,7 +764,7 @@ MessagesAdapter::startSearch(QString& text, bool isMedia)
 }
 
 int
-MessagesAdapter::getMessageIndexFromId(QString& id)
+MessagesAdapter::getMessageIndexFromId(const QString& id)
 {
     const QString& convId = lrcInstance_->get_selectedConvUid();
     const auto& conversation = lrcInstance_->getConversationFromConvUid(convId);
