@@ -28,6 +28,9 @@
 
 #include <QSortFilterProxyModel>
 
+class AppSettingsManager;
+class MessageParser;
+
 class FilteredMsgListModel final : public QSortFilterProxyModel
 {
     Q_OBJECT
@@ -50,8 +53,6 @@ public:
     };
 };
 
-class AppSettingsManager;
-
 class MessagesAdapter final : public QmlAdapterBase
 {
     Q_OBJECT
@@ -74,9 +75,9 @@ Q_SIGNALS:
     void newMessageBarPlaceholderText(QString& placeholderText);
     void newFilePasted(QString filePath);
     void newTextPasted();
-    void previewInformationToQML(QString messageId, QStringList previewInformation);
     void moreMessagesLoaded(qint32 loadingRequestId);
     void timestampUpdated();
+    void fileCopied(const QString& dest);
 
 protected:
     Q_INVOKABLE bool isDocument(const interaction::Type& type);
@@ -122,18 +123,19 @@ protected:
     Q_INVOKABLE QString getFormattedDay(const quint64 timestamp);
     Q_INVOKABLE QString getFormattedTime(const quint64 timestamp);
     Q_INVOKABLE QString getBestFormattedDate(const quint64 timestamp);
-    Q_INVOKABLE void parseMessageUrls(const QString& messageId,
-                                      const QString& msg,
-                                      bool showPreview,
-                                      QColor color = "#0645AD");
+    Q_INVOKABLE void parseMessage(const QString& msgId,
+                                  const QString& msg,
+                                  bool previewLinks,
+                                  const QColor& linkColor = QColor(0x06, 0x45, 0xad),
+                                  const QColor& backgroundColor = QColor(0x0, 0x0, 0x0));
     Q_INVOKABLE void onPaste();
     Q_INVOKABLE int getIndexOfMessage(const QString& messageId) const;
     Q_INVOKABLE QString getStatusString(int status);
     Q_INVOKABLE QVariantMap getTransferStats(const QString& messageId, int);
     Q_INVOKABLE QVariant dataForInteraction(const QString& interactionId,
                                             int role = Qt::DisplayRole) const;
-    Q_INVOKABLE void startSearch(QString& text, bool isMedia = false);
-    Q_INVOKABLE int getMessageIndexFromId(QString& id);
+    Q_INVOKABLE void startSearch(const QString& text, bool isMedia);
+    Q_INVOKABLE int getMessageIndexFromId(const QString& id);
 
     // Run corrsponding js functions, c++ to qml.
     void setMessagesImageContent(const QString& path, bool isBased64 = false);
@@ -146,9 +148,9 @@ private Q_SLOTS:
     void onNewInteraction(const QString& convUid,
                           const QString& interactionId,
                           const interaction::Info& interaction);
-    void onPreviewInfoReady(QString messageIndex, QVariantMap urlInMessage);
+    void onMessageParsed(const QString& messageId, const QString& parsed);
+    void onLinkInfoReady(const QString& messageIndex, const QVariantMap& info);
     void onConversationMessagesLoaded(uint32_t requestId, const QString& convId);
-    void onMessageLinkified(const QString& messageId, const QString& linkified);
     void onComposingStatusChanged(const QString& convId,
                                   const QString& contactUri,
                                   bool isComposing);
@@ -159,7 +161,8 @@ private:
     QList<QString> conversationTypersUrlToName(const QSet<QString>& typersSet);
 
     AppSettingsManager* settingsManager_;
-    PreviewEngine* previewEngine_;
+    MessageParser* messageParser_;
+
     FilteredMsgListModel* filteredMsgListModel_;
 
     static constexpr const int loadChunkSize_ {20};
