@@ -51,6 +51,35 @@
 #include <windows.h>
 #endif
 
+// Removes the given argument from the command line arguments, and invokes the callback
+// function with the removed argument if it was found.
+// This is required for custom args as quick_test_main_with_setup() will
+// fail if given an invalid command-line argument.
+void
+Utils::remove_argument(char** argv,
+                       int& argc,
+                       const std::string& arg_to_remove,
+                       std::function<void()> callback)
+{
+    // Remove arg_to_remove from argv, as quick_test_main_with_setup() will
+    // fail if given an invalid command-line argument.
+    auto new_end = std::remove_if(argv + 1, argv + argc, [&](char* arg_ptr) {
+        if (std::string(arg_ptr).compare(arg_to_remove) == 0) {
+            // Invoke the callback function with the removed argument.
+            callback();
+            return true;
+        } else {
+            return false;
+        }
+    });
+
+    // If any occurrences were removed...
+    if (new_end != argv + argc) {
+        // Adjust the argument count.
+        argc = std::distance(argv, new_end);
+    }
+}
+
 void
 Utils::testVulkanSupport()
 {
@@ -312,7 +341,7 @@ Utils::GetRingtonePath()
 #ifdef Q_OS_WIN
     return QCoreApplication::applicationDirPath() + "\\ringtones\\default.opus";
 #else
-    return QString("/usr/share/ring/ringtones/default.opus");
+    return QString("/usr/share/jami/ringtones/default.opus");
 #endif
 }
 
@@ -440,16 +469,19 @@ Utils::conversationAvatar(LRCInstance* instance,
         auto members = convModel->peersForConversation(convId);
         if (members.size() < 1)
             return avatar;
+        auto getPhoto = [&](const auto& uri) {
+            return uri == accInfo.profileInfo.uri ? accountPhoto(instance, accountId, size)
+                                                  : contactPhoto(instance, uri, size, "");
+        };
         if (members.size() == 1) {
             // Only member in the swarm or 1:1, draw only peer's avatar
-            auto peerAvatar = Utils::contactPhoto(instance, members[0], size, "");
+            auto peerAvatar = getPhoto(members[0]);
             painter.drawImage(avatar.rect(), peerAvatar);
             return avatar;
         }
         // Else, combine avatars
-        auto idx = 0;
-        auto peerAAvatar = Utils::contactPhoto(instance, members[0], size, "");
-        auto peerBAvatar = Utils::contactPhoto(instance, members[1], size, "");
+        auto peerAAvatar = getPhoto(members[0]);
+        auto peerBAvatar = getPhoto(members[1]);
         peerAAvatar = Utils::halfCrop(peerAAvatar, true);
         peerBAvatar = Utils::halfCrop(peerBAvatar, false);
         painter.drawImage(avatar.rect(), peerAAvatar);
@@ -679,7 +711,8 @@ Utils::fallbackAvatar(const QString& canonicalUri, const QString& name, const QS
     // if a letter was passed, then we paint a letter in the circle,
     // otherwise we draw the default avatar icon
     QString trimmedName(name);
-    if (!trimmedName.remove(QRegularExpression("[\\n\\t\\r]")).isEmpty()) {
+    const static QRegularExpression newlineRe("[\\n\\t\\r]");
+    if (!trimmedName.remove(newlineRe).isEmpty()) {
         auto unicode = trimmedName.toUcs4().at(0);
         if (unicode >= 0x1F000 && unicode <= 0x1FFFF) {
             // emoticon
