@@ -20,7 +20,6 @@
 #include "api/avmodel.h"
 
 #include "api/video.h"
-#include "api/call.h"
 #include "api/lrc.h"
 #ifdef ENABLE_LIBWRAP
 #include "directrenderer.h"
@@ -39,6 +38,7 @@
 #include <QtCore/QDir>
 #include <QUrl>
 #include <QSize>
+#include <QReadWriteLock>
 
 #include <algorithm> // std::sort
 #include <chrono>
@@ -76,7 +76,7 @@ public:
     static const QString recorderSavesSubdir;
     AVModel& linked_;
 
-    std::mutex renderers_mtx_;
+    QReadWriteLock renderersMutex_;
     std::map<QString, std::unique_ptr<Renderer>> renderers_;
     QString currentVideoCaptureDevice_ {};
 
@@ -103,10 +103,12 @@ public:
     void addRenderer(const QString& id, const QSize& res, const QString& shmPath = {});
 
     /**
-     * Remove renderer from renderers_
+     * Remove renderer from renderers_. If the returned renderer is ignored, it
+     * will be deleted.
      * @param id
+     * @return the renderer
      */
-    void removeRenderer(const QString& id);
+    std::unique_ptr<Renderer> removeRenderer(const QString& id);
 
     bool hasRenderer(const QString& id);
     QSize getRendererSize(const QString& id);
@@ -167,7 +169,7 @@ AVModel::AVModel(const CallbacksHandler& callbacksHandler)
 
 AVModel::~AVModel()
 {
-    std::lock_guard<std::mutex> lk(pimpl_->renderers_mtx_);
+    QWriteLocker lk(&pimpl_->renderersMutex_);
     for (auto r = pimpl_->renderers_.begin(); r != pimpl_->renderers_.end(); ++r) {
         (*r).second.reset();
     }
@@ -177,7 +179,7 @@ QList<MapStringString>
 AVModel::getRenderersInfo(QString id)
 {
     QList<MapStringString> infoList;
-    std::lock_guard<std::mutex> lk(pimpl_->renderers_mtx_);
+    QReadLocker lk(&pimpl_->renderersMutex_);
     for (auto r = pimpl_->renderers_.begin(); r != pimpl_->renderers_.end(); r++) {
         MapStringString qmap;
         auto& rend = r->second;
@@ -196,14 +198,17 @@ AVModel::getRenderersInfo(QString id)
 void
 AVModel::updateRenderersFPSInfo(QString rendererId)
 {
-    std::unique_lock<std::mutex> lk(pimpl_->renderers_mtx_);
+    QReadLocker lk(&pimpl_->renderersMutex_);
     auto it = std::find_if(pimpl_->renderers_.begin(),
                            pimpl_->renderers_.end(),
                            [&rendererId](const auto& c) {
                                return rendererId == c.second->getInfos()["RENDERER_ID"];
                            });
-    if (it != pimpl_->renderers_.end())
-        Q_EMIT onRendererFpsChange(qMakePair(rendererId, it->second->getInfos()["FPS"]));
+    if (it != pimpl_->renderers_.end()) {
+        auto fpsInfo = qMakePair(rendererId, it->second->getInfos()["FPS"]);
+        lk.unlock();
+        Q_EMIT onRendererFpsChange(fpsInfo);
+    }
 }
 
 bool
@@ -334,7 +339,7 @@ AVModel::setDeviceSettings(video::Settings& settings)
 
     // If the preview is running, reload it
     // doing this during a call will cause re-invite, this is unwanted
-    std::unique_lock<std::mutex> lk(pimpl_->renderers_mtx_);
+    QReadLocker lk(&pimpl_->renderersMutex_);
     auto it = pimpl_->renderers_.find(video::PREVIEW_RENDERER_ID);
     if (it != pimpl_->renderers_.end() && it->second && pimpl_->renderers_.size() == 1) {
         lk.unlock();
@@ -734,7 +739,7 @@ AVModel::getListWindows() const
         auto finishedloop = true;
     } catch (...) {
     }
- #endif
+#endif
     return ret;
 }
 
@@ -943,12 +948,21 @@ createRenderer(const QString& id, const QSize& res, const QString& shmPath = {})
 void
 AVModelPimpl::addRenderer(const QString& id, const QSize& res, const QString& shmPath)
 {
-    auto connectRenderer = [this](Renderer* renderer, const QString& id) {
+    // Remove the renderer if it already exists.
+    std::ignore = removeRenderer(id);
+
+    {
+        QWriteLocker lk(&renderersMutex_);
+        renderers_[id] = createRenderer(id, res, shmPath);
+    }
+
+    QReadLocker lk(&renderersMutex_);
+    if (auto* renderer = renderers_.find(id)->second.get()) {
         connect(
             renderer,
             &Renderer::fpsChanged,
             this,
-            [this, id](void) { Q_EMIT linked_.updateRenderersFPSInfo(id); },
+            [this, id](void) { linked_.updateRenderersFPSInfo(id); },
             Qt::QueuedConnection);
         connect(
             renderer,
@@ -956,12 +970,14 @@ AVModelPimpl::addRenderer(const QString& id, const QSize& res, const QString& sh
             this,
             [this, id](const QSize& size) { Q_EMIT linked_.rendererStarted(id, size); },
             Qt::DirectConnection);
+#ifdef ENABLE_LIBWRAP
         connect(
             renderer,
             &Renderer::frameBufferRequested,
             this,
             [this, id](AVFrame* frame) { Q_EMIT linked_.frameBufferRequested(id, frame); },
             Qt::DirectConnection);
+#endif
         connect(
             renderer,
             &Renderer::frameUpdated,
@@ -974,39 +990,36 @@ AVModelPimpl::addRenderer(const QString& id, const QSize& res, const QString& sh
             this,
             [this, id] { Q_EMIT linked_.rendererStopped(id); },
             Qt::DirectConnection);
-    };
-    std::lock_guard<std::mutex> lk(renderers_mtx_);
-    renderers_.erase(id); // Because it should be done before creating the renderer
-    auto renderer = createRenderer(id, res, shmPath);
-    auto& r = renderers_[id];
-    r = std::move(renderer);
-    connectRenderer(r.get(), id);
-    r->startRendering();
+
+        renderer->startRendering();
+    }
 }
 
-void
+std::unique_ptr<Renderer>
 AVModelPimpl::removeRenderer(const QString& id)
 {
-    std::lock_guard<std::mutex> lk(renderers_mtx_);
+    QWriteLocker lk(&renderersMutex_);
     auto it = renderers_.find(id);
     if (it == renderers_.end()) {
         qWarning() << "Cannot remove renderer. " << id << "not found";
-        return;
+        return {};
     }
-    renderers_.erase(id);
+    auto removed = std::move(it->second);
+    renderers_.erase(it);
+    return removed;
 }
 
 bool
 AVModelPimpl::hasRenderer(const QString& id)
 {
-    std::lock_guard<std::mutex> lk(renderers_mtx_);
+    QReadLocker lk(&renderersMutex_);
     return renderers_.find(id) != renderers_.end();
 }
 
 QSize
 AVModelPimpl::getRendererSize(const QString& id)
 {
-    std::lock_guard<std::mutex> lk(renderers_mtx_);
+    QReadLocker lk(&renderersMutex_);
     auto it = renderers_.find(id);
     if (it != renderers_.end()) {
         return it->second->size();
@@ -1017,7 +1030,7 @@ AVModelPimpl::getRendererSize(const QString& id)
 Frame
 AVModelPimpl::getRendererFrame(const QString& id)
 {
-    std::lock_guard<std::mutex> lk(renderers_mtx_);
+    QReadLocker lk(&renderersMutex_);
     auto it = renderers_.find(id);
     if (it != renderers_.end()) {
         return it->second->currentFrame();
