@@ -309,6 +309,8 @@ ContactModel::addContact(contact::Info contactInfo)
     Q_EMIT profileUpdated(profile.uri);
     if (profile.type == profile::Type::SIP)
         Q_EMIT contactAdded(profile.uri);
+    else
+        ConfigurationManager::instance().lookupAddress(owner.id, "", profile.uri);
 }
 
 void
@@ -416,9 +418,9 @@ ContactModel::searchContact(const QString& query)
     pimpl_->searchResult.clear();
 
     auto uri = URI(query);
-    QString uriID = uri.format(URI::Section::USER_INFO | URI::Section::HOSTNAME
+    QString uriId = uri.format(URI::Section::USER_INFO | URI::Section::HOSTNAME
                                | URI::Section::PORT);
-    pimpl_->searchQuery = uriID;
+    pimpl_->searchQuery = uriId;
 
     auto uriScheme = uri.schemeType();
     if (static_cast<int>(uriScheme) > 2 && owner.profileInfo.type == profile::Type::SIP) {
@@ -450,11 +452,11 @@ ContactModelPimpl::updateTemporaryMessage(const QString& mes)
 void
 ContactModelPimpl::searchContact(const URI& query)
 {
-    QString uriID = query.format(URI::Section::USER_INFO | URI::Section::HOSTNAME
+    QString uriId = query.format(URI::Section::USER_INFO | URI::Section::HOSTNAME
                                  | URI::Section::PORT);
     if (query.isEmpty()) {
         // This will remove the temporary item
-        Q_EMIT linked.modelUpdated(uriID);
+        Q_EMIT linked.modelUpdated(uriId);
         updateTemporaryMessage("");
         return;
     }
@@ -462,51 +464,49 @@ ContactModelPimpl::searchContact(const URI& query)
     if (query.protocolHint() == URI::ProtocolHint::RING) {
         updateTemporaryMessage("");
         // no lookup, this is a ring infoHash
-        for (auto& i : contacts) {
-            if (i.profileInfo.uri == uriID) {
+        for (auto& i : contacts)
+            if (i.profileInfo.uri == uriId)
                 return;
-            }
-        }
-        auto& temporaryContact = searchResult[uriID];
-        temporaryContact.profileInfo.uri = uriID;
-        temporaryContact.profileInfo.alias = uriID;
+        auto& temporaryContact = searchResult[uriId];
+        temporaryContact.profileInfo.uri = uriId;
+        temporaryContact.profileInfo.alias = uriId;
         temporaryContact.profileInfo.type = profile::Type::TEMPORARY;
-        Q_EMIT linked.modelUpdated(uriID);
+        Q_EMIT linked.modelUpdated(uriId);
     } else {
         updateTemporaryMessage(tr("Searching…"));
 
         // If the username contains an @ it's an exact match
         bool isJamsAccount = !linked.owner.confProperties.managerUri.isEmpty();
         if (isJamsAccount and not query.hasHostname())
-            ConfigurationManager::instance().searchUser(linked.owner.id, uriID);
+            ConfigurationManager::instance().searchUser(linked.owner.id, uriId);
         else
-            ConfigurationManager::instance().lookupName(linked.owner.id, "", uriID);
+            ConfigurationManager::instance().lookupName(linked.owner.id, "", uriId);
     }
 }
 
 void
 ContactModelPimpl::searchSipContact(const URI& query)
 {
-    QString uriID = query.format(URI::Section::USER_INFO | URI::Section::HOSTNAME
+    QString uriId = query.format(URI::Section::USER_INFO | URI::Section::HOSTNAME
                                  | URI::Section::PORT);
     if (query.isEmpty()) {
         // This will remove the temporary item
-        Q_EMIT linked.modelUpdated(uriID);
+        Q_EMIT linked.modelUpdated(uriId);
         updateTemporaryMessage("");
         return;
     }
 
     {
         std::lock_guard<std::mutex> lk(contactsMtx_);
-        if (contacts.find(uriID) == contacts.end()) {
+        if (contacts.find(uriId) == contacts.end()) {
             auto& temporaryContact = searchResult[query];
 
-            temporaryContact.profileInfo.uri = uriID;
-            temporaryContact.profileInfo.alias = uriID;
+            temporaryContact.profileInfo.uri = uriId;
+            temporaryContact.profileInfo.alias = uriId;
             temporaryContact.profileInfo.type = profile::Type::TEMPORARY;
         }
     }
-    Q_EMIT linked.modelUpdated(uriID);
+    Q_EMIT linked.modelUpdated(uriId);
 }
 
 uint64_t
@@ -1209,16 +1209,15 @@ ContactModelPimpl::slotProfileReceived(const QString& accountId,
             profileInfo.alias = e.split(":")[1];
 
     if (peer == linked.owner.profileInfo.uri) {
-        if (!profileInfo.avatar.isEmpty()) {
-            auto dest = storage::getPath() + accountId + "/profile.vcf";
-            QFile oldvCard(dest);
-            if (oldvCard.exists())
-                oldvCard.remove();
-            vCardFile.rename(dest);
-            linked.owner.accountModel->setAlias(linked.owner.id, profileInfo.alias);
-            linked.owner.accountModel->setAvatar(linked.owner.id, profileInfo.avatar);
-            Q_EMIT linked.profileUpdated(peer);
-        }
+        auto avatarChanged = profileInfo.avatar != linked.owner.profileInfo.avatar;
+        auto aliasChanged = profileInfo.alias != linked.owner.profileInfo.alias;
+        if (profileInfo.avatar.isEmpty())
+            return; // In this case, probably a new device without avatar.
+        // Only save the new profile once
+        if (aliasChanged)
+            linked.owner.accountModel->setAlias(linked.owner.id, profileInfo.alias, !avatarChanged);
+        if (avatarChanged)
+            linked.owner.accountModel->setAvatar(linked.owner.id, profileInfo.avatar, true);
         return;
     }
     vCardFile.remove();
